"""
brewer2mpl is a pure Python package for accessing
colorbrewer2.org color maps from Python. With brewer2mpl you can get the
raw RGB colors of all 165 colorbrewer2.org color maps.

"""
from .brewer2mpl import *
from . import wesanderson

__version__ = '1.4'
